@@ -71,12 +71,7 @@ QVariant ArchiveModel::data(const QModelIndex &index, int role) const
             case FullPath:
                 return entry->name();
             case Size:
-                if (entry->isDir()) {
-                    uint dirs;
-                    uint files;
-                    entry->countChildren(dirs, files);
-                    return KIO::itemsSummaryString(dirs + files, files, dirs, 0, false);
-                } else if (!entry->property("link").toString().isEmpty()) {
+                if (!entry->property("link").toString().isEmpty()) {
                     return QVariant();
                 } else {
                     return KIO::convertSize(entry->property("size").toULongLong());
@@ -136,10 +131,9 @@ QVariant ArchiveModel::data(const QModelIndex &index, int role) const
 
 Qt::ItemFlags ArchiveModel::flags(const QModelIndex &index) const
 {
-    Qt::ItemFlags defaultFlags = QAbstractItemModel::flags(index);
-
     if (index.isValid()) {
-        return Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | defaultFlags;
+        const auto itemFlags = Qt::ItemIsEnabled | Qt::ItemIsSelectable | QAbstractItemModel::flags(index);
+        return index.column() ? itemFlags : itemFlags | Qt::ItemIsDragEnabled;
     }
 
     return Qt::NoItemFlags;
@@ -160,9 +154,9 @@ QVariant ArchiveModel::headerData(int section, Qt::Orientation, int role) const
         case FullPath:
             return i18nc("Name of a file inside an archive", "Name");
         case Size:
-            return i18nc("Uncompressed size of a file inside an archive", "Size");
+            return i18nc("Uncompressed size of a file inside an archive", "Original Size");
         case CompressedSize:
-            return i18nc("Compressed size of a file inside an archive", "Compressed");
+            return i18nc("Compressed size of a file inside an archive", "Compressed Size");
         case Ratio:
             return i18nc("Compression rate of file", "Rate");
         case Owner:
@@ -829,28 +823,30 @@ void ArchiveModel::countEntriesAndSize()
 
     m_numberOfFiles = 0;
     m_numberOfFolders = 0;
-    m_uncompressedSize = 0;
 
     QElapsedTimer timer;
     timer.start();
 
-    traverseAndCountDirNode(m_rootEntry.data());
+    traverseAndComputeDirSizes(m_rootEntry.data());
 
     qCDebug(ARK) << "Time to count entries and size:" << timer.elapsed() << "ms";
 }
 
-void ArchiveModel::traverseAndCountDirNode(Archive::Entry *dir)
+qulonglong ArchiveModel::traverseAndComputeDirSizes(Archive::Entry *dir)
 {
     const auto entries = dir->entries();
+    qulonglong uncompressedSize = 0;
     for (Archive::Entry *entry : entries) {
         if (entry->isDir()) {
-            traverseAndCountDirNode(entry);
             m_numberOfFolders++;
+            uncompressedSize += traverseAndComputeDirSizes(entry);
         } else {
             m_numberOfFiles++;
-            m_uncompressedSize += entry->property("size").toULongLong();
+            uncompressedSize += entry->property("size").toULongLong();
         }
     }
+    dir->setProperty("size", uncompressedSize);
+    return uncompressedSize;
 }
 
 qulonglong ArchiveModel::numberOfFiles() const
@@ -865,7 +861,7 @@ qulonglong ArchiveModel::numberOfFolders() const
 
 qulonglong ArchiveModel::uncompressedSize() const
 {
-    return m_uncompressedSize;
+    return m_rootEntry.data()->property("size").toULongLong();
 }
 
 QList<int> ArchiveModel::shownColumns() const
